Other components — SnapPy 3.2 documentation

# Other components

SnapPy incorporates:

## Ptolemy module

The ptolemy module for studying representations of 3-manifold groups into SL(N, C) and PSL(N, C). By Matthias Goerner.

- The ptolemy module
  - What is the ptolemy module?
  - Documentation
    - Mathematical preliminaries
    - Step-by-step examples: Part 1
    - Step-by-step examples: Part 2
    - Step-by-step examples: Part 3
    - Step-by-step examples: Part 4
    - Classes

## Twister

Twister for building surface bundles and Heegaard splittings from mapping class group data. By Marc Bell, Tracy Hall, and Saul Schleimer.